/**
 * @param {ParentNode|Element} source
 * @param {string} selector
 * @returns {HTMLElement|null}
 */
export const getElement = (source, selector) => source.querySelector(selector);

/**
 * @param {ParentNode|Element} source
 * @param {string} selector
 * @returns {HTMLElement[]}
 */
export const getElements = (source, selector) => {
    const list = source.querySelectorAll(selector);

    return [...list]
};

/**
 * @param {ParentNode|Element} source
 * @param {string} selector
 * @returns {HTMLElement}
 */
export const getElementOrThrow = (source, selector) => {
    const element = getElement(source, selector);

    if (!element) {
        throw new Error(`Element ${selector} not found in ${source}`);
    }

    return element;
}

/**
 * @param {ParentNode|Element} source
 * @param {string} selector
 * @returns {HTMLElement[]}
 */
export const getElementsOrThrow = (source, selector) => {
    const elements = getElements(source, selector);

    if (elements.length <= 0) {
        throw new Error(`No elements found with ${selector} in ${source}`);
    }

    return elements
}

/**
 * @param {ParentNode|Element} source
 * @param {string} selector
 * @returns {HTMLElement}
 */
export const getOneElementOrThrow = (source, selector) => {
    const elements = getElementsOrThrow(source, selector);

    if (elements.length > 1) {
        throw new Error(`Found more then 1 element with ${selector} in ${source}`);
    }

    return elements[0]
}