import {homeDir} from "./path.js";
import {exists, readDir} from "./fs.js";

const eventBus = new Comment();

const NAVIGATE_EVENT = 'navigate';

let currentDir = await homeDir();

/**
 * @param {function} callback
 */
export const onNavigate = (callback) => eventBus.addEventListener(
    NAVIGATE_EVENT,
    () => callback(currentDir)
);

/**
 * @param {function} callback
 */
export const onceNavigate = (callback) => eventBus.addEventListener(
    NAVIGATE_EVENT,
    () => callback(currentDir),
    { once: true }
);

/**
 * @param {string} toDir
 */
export const navigate = async (toDir) => {
    const dirExists =await exists(toDir);
    if (!dirExists) throw new Error(`Target dir does not exists: ${toDir}`);

    if (!toDir.endsWith('/')) {
        toDir = toDir + '/'
    }

    currentDir = toDir;
    eventBus.dispatchEvent(new CustomEvent(NAVIGATE_EVENT))
}

/**
 * @returns {string}
 */
export const getCurrentDir = () => currentDir;

const logDir = async () => console.log({
    currentDir,
    items: await readDir(currentDir)
});